
# THIS FILE IS GENERATED FROM ORANGE SETUP.PY
short_version = '3.15.0'
version = '3.15.0'
full_version = '3.15.0'
git_revision = 'bf95ddcd2b3c718fca8ab7b4c409de471c66c2c3'
release = True

if not release:
    version = full_version
    short_version += ".dev"
